@@ -1,9 +1,9 @@
-import json
-from asyncio import BaseEventLoop
 from typing import Optional, List
+from asyncio import BaseEventLoop
+import json
 
-from asyncpg import create_pool
 from asyncpg.connection import Connection
+from asyncpg import create_pool
 from asyncpg.pool import Pool
 
 from postDB.model.meta import ModelMeta
@@ -26,6 +26,8 @@ def format_missing(missing):
 
 
 class Model(metaclass=ModelMeta):
+    """Base class for all the models."""
+
     pool: Optional[Pool] = None
 
     def __init__(self, **attrs):
@@ -55,8 +57,8 @@ class Model(metaclass=ModelMeta):
             )
 
     @classmethod
-    def create_table_sql(cls, *, exists_ok: bool = True):
-        """Generates the CREATE TABLE statement."""
+    def create_table_sql(cls, *, exists_ok: bool = True) -> str:
+        """Generates the ``CREATE TABLE`` SQL statement."""
         statements = []
         builder = ["CREATE TABLE"]
 
@@ -93,13 +95,15 @@ class Model(metaclass=ModelMeta):
         return "\n".join(statements)
 
     @classmethod
-    def drop_table_sql(cls, exists_ok: bool = True):
+    def drop_table_sql(cls, *, exists_ok: bool = True, cascade: bool = False) -> str:
+        """Generates the ``DROP TABLE`` SQL statement."""
         builder = ["DROP TABLE"]
 
         if exists_ok:
             builder.append("IF EXISTS")
 
-        builder.append("%s CASCADE;" % cls.__tablename__)
+        to_cascade = "CASCADE" if cascade else "RESTRICT"
+        builder.append("%s %s;" % (cls.__tablename__, to_cascade))
         return " ".join(builder)
 
     @classmethod
@@ -142,7 +146,7 @@ class Model(metaclass=ModelMeta):
             return await cls.pool.acquire()
 
         raise RuntimeWarning(
-            f"Unable to get Connection, either call `Model.create_pool` or provide a `con` arg."
+            "Unable to get Connection, either call `Model.create_pool` or provide a `con` argument."
         )
 
     @classmethod
@@ -169,12 +173,13 @@ class Model(metaclass=ModelMeta):
         con: Optional[Connection] = None,
         *,
         verbose: bool = False,
+        cascade: bool = True,
         exists_ok: bool = True,
     ):
         """Drop the PostgreSQL Table for this Model."""
         con = await cls.ensure_con(con=con)
 
-        sql = cls.drop_table_sql(exists_ok=exists_ok)
+        sql = cls.drop_table_sql(exists_ok=exists_ok, cascade=cascade)
 
         if verbose:
             print(sql)
@@ -183,7 +188,7 @@ class Model(metaclass=ModelMeta):
 
     @classmethod
     def all_models(cls) -> List["Model"]:
-        """Returns a list of all `Model` subclasses."""
+        """Returns a list of all :class:`Model` subclasses."""
         return cls.__subclasses__()
 
     def as_dict(self, *columns) -> dict:
